@@ -5,7 +5,9 @@ namespace statistics {
 
     double mean(const std::vector<double>& data) {
         double sum = 0.0;
-        for (auto it = data.begin(); it != data.end(); it++)
+        std::vector<double>::const_iterator it;
+
+        for (it = data.begin(); it != data.end(); it++)
             sum += *it;
         return sum / data.size();
     }
@@ -13,7 +15,9 @@ namespace statistics {
     double variance(const std::vector<double>& data) {
         double sum = 0.0;
         double avg = mean(data);
-        for (auto it = data.begin(); it != data.end(); it++)
+        std::vector<double>::const_iterator it;
+
+        for (it = data.begin(); it != data.end(); it++)
             sum += std::pow(*it - avg, 2);
         return sum / data.size();
     }
