@@ -1,7 +1,9 @@
 #include <cmath>
+#include <math.h> // for the erf() function, std::erf was added to C++ recently
 #include <ostream>
-#include "MathFunctions.hpp"
+#include <sstream>
 #include "GaussianDistribution.hpp"
+#include "MathFunctions.hpp"
 
 namespace statistics {
 
@@ -13,7 +15,7 @@ namespace statistics {
 
     double GaussianDistribution::cdf(const double x) const {
         double erfparam = (SQRT2/2.0) * (x - mu) / sigma;
-        return  (1.0 + std::erf(erfparam)) / 2.0;
+        return  (1.0 + erf(erfparam)) / 2.0;
     }
 
     double GaussianDistribution::expectedvalue() const {
@@ -26,10 +28,10 @@ namespace statistics {
 
     std::ostream& operator<<(std::ostream& os, const GaussianDistribution& dist) {
         os << "Gaussian distributed variable with:" << std::endl
-          << "  Mu: " << std::to_string(dist.mu) << std::endl
-          << "  Sigma: " << std::to_string(dist.sigma) << std::endl
-          << "  E(X): " << std::to_string(dist.expectedvalue()) << std::endl
-          << "  Var(X): " << std::to_string(dist.variance()) << std::endl;
+          << "  Mu: " << dist.mu << std::endl
+          << "  Sigma: " << dist.sigma << std::endl
+          << "  E(X): " << dist.expectedvalue() << std::endl
+          << "  Var(X): " << dist.variance() << std::endl;
         return os;
     }
 
