@@ -84,10 +84,10 @@ class ProbabilityDistributions(unittest.TestCase):
         self.assertAlmostEqual(40000.0, e.variance())
 
         expected = ('Gaussian distributed variable with:\n'
-                    '  Mu: 1500.000000\n'
-                    '  Sigma: 200.000000\n'
-                    '  E(X): 1500.000000\n'
-                    '  Var(X): 40000.000000\n')
+                    '  Mu: 1500\n'
+                    '  Sigma: 200\n'
+                    '  E(X): 1500\n'
+                    '  Var(X): 40000\n')
         self.assertEqual(expected, str(e))
 
 
